
current_menu_appears = """
        Quickly setup your work environment run commands from the menu.
        Currently you may choose one below or create your own functions and
        add to this list following instructions on Readme.md
        --------------------------------------------------
                             M E N U
        --------------------------------------------------
                       1. check setup
                       2. setup
                       3. create user options file
                       4. create series file
                       5. add new series group
                       6. get data
                       7. get categories
                       8. help
                       9. show api key
                       10. save api key to file
                       11. remove cache folders
                       12. evdspy as a command line prompt
                       13. version
                       14. console
"""